@@ -210,7 +210,7 @@ pub fn pack_or_pack_index(
                     }
                     if let Some(verifier) = object_verifier.as_ref() {
                         let mut obj = verifier.locate(written_id.to_borrowed())
-                                            .ok_or_else(|| Error::WrittenFileMissing(written_id))?
+                                            .ok_or(Error::WrittenFileMissing(written_id))?
                                             .map_err(|err| Error::WrittenFileCorrupt(err, written_id))?;
                         obj.verify_checksum(written_id.to_borrowed())?;
                     }
@@ -218,7 +218,7 @@ pub fn pack_or_pack_index(
                 }
             }
         },
-        pack::cache::DecodeEntryLRU::default,
+        pack::cache::LRU::default,
         pack::index::traverse::Options {
             algorithm,
             thread_limit,
